( cd usr/lib/mono/2.0 ; rm -rf mod-mono-server2.exe )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/mod-mono-server2/2.0.0.0__0738eb9f132ed756/mod-mono-server2.exe mod-mono-server2.exe )
( cd usr/lib/mono/2.0 ; rm -rf Mono.WebServer2.dll )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/Mono.WebServer2/0.2.0.0__0738eb9f132ed756/Mono.WebServer2.dll Mono.WebServer2.dll )
( cd usr/lib/mono/2.0 ; rm -rf fastcgi-mono-server2.exe )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/fastcgi-mono-server2/2.0.0.0__0738eb9f132ed756/fastcgi-mono-server2.exe fastcgi-mono-server2.exe )
( cd usr/lib/mono/2.0 ; rm -rf xsp2.exe )
( cd usr/lib/mono/2.0 ; ln -sf ../gac/xsp2/2.0.0.0__0738eb9f132ed756/xsp2.exe xsp2.exe )
( cd usr/lib/mono/1.0 ; rm -rf mod-mono-server.exe )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/mod-mono-server/2.0.0.0__0738eb9f132ed756/mod-mono-server.exe mod-mono-server.exe )
( cd usr/lib/mono/1.0 ; rm -rf fastcgi-mono-server.exe )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/fastcgi-mono-server/2.0.0.0__0738eb9f132ed756/fastcgi-mono-server.exe fastcgi-mono-server.exe )
( cd usr/lib/mono/1.0 ; rm -rf Mono.WebServer.dll )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/Mono.WebServer/0.1.0.0__0738eb9f132ed756/Mono.WebServer.dll Mono.WebServer.dll )
( cd usr/lib/mono/1.0 ; rm -rf xsp.exe )
( cd usr/lib/mono/1.0 ; ln -sf ../gac/xsp/2.0.0.0__0738eb9f132ed756/xsp.exe xsp.exe )
