<%@ Page language="C#" %>
<%@ Register TagPrefix="mono" TagName="MonoSamplesHeader" src="~/controls/MonoSamplesHeader.ascx" %>
<html>
<head>
<link rel="stylesheet" type="text/css" href="/mono-xsp.css">
</head>
<body><mono:MonoSamplesHeader runat="server"/>
<form runat="server">
<asp:Table runat='server'>
<asp:TableRow runat='server'>
<asp:TableCell runat='server'>
TEST
</asp:TableCell>
</asp:TableRow>
</asp:Table>
</form>
</body>
</html>
