<form runat="server">
    <Acme:One id="One" Text="This is a default One!" Color="blue" runat="server"/>
    <p>
    <Acme:Two id="Two" Text="This is a default Two!" Color="blue" runat="server"/>
    <p>
    <Acme:Label id="Three" Text="This is a label!" Color="blue" runat="server"/>
    <p>

    <asp:Button text="Change" OnClick="Clicked" runat=server/>

</form>

